==> qtjambi-qt3drender-6.6.0-sources.jar: io/qt/qt3d/render/QEffect.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Base class for effects in a Qt 3D scene</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qeffect.html">Qt3DRender::QEffect</a></code></p>
 */
public class QEffect extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QEffect.class);
    
    
    /**
     * <p>See <code>Qt3DRender::QEffect::<wbr>QEffect(Qt3DCore::QNode*)</code></p>
     */
    @SuppressWarnings({"exports"})
    public QEffect(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QEffect instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qeffect.html#addParameter">Qt3DRender::QEffect::<wbr>addParameter(Qt3DRender::QParameter*)</a></code></p>
     */
    @QtUninvokable
    public final void addParameter(io.qt.qt3d.render.@Nullable QParameter parameter){
        addParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parameter));
    }
    
    @QtUninvokable
    private native void addParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long parameter);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qeffect.html#addTechnique">Qt3DRender::QEffect::<wbr>addTechnique(Qt3DRender::QTechnique*)</a></code></p>
     */
    @QtUninvokable
    public final void addTechnique(io.qt.qt3d.render.@Nullable QTechnique t){
        addTechnique_native_Qt3DRender_QTechnique_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(t));
    }
    
    @QtUninvokable
    private native void addTechnique_native_Qt3DRender_QTechnique_ptr(long __this__nativeId, long t);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qeffect.html#parameters">Qt3DRender::QEffect::<wbr>parameters()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.qt3d.render.@Nullable QParameter> parameters(){
        return parameters_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.qt3d.render.QParameter> parameters_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qeffect.html#removeParameter">Qt3DRender::QEffect::<wbr>removeParameter(Qt3DRender::QParameter*)</a></code></p>
     */
    @QtUninvokable
    public final void removeParameter(io.qt.qt3d.render.@Nullable QParameter parameter){
        removeParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parameter));
    }
    
    @QtUninvokable
    private native void removeParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long parameter);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qeffect.html#removeTechnique">Qt3DRender::QEffect::<wbr>removeTechnique(Qt3DRender::QTechnique*)</a></code></p>
     */
    @QtUninvokable
    public final void removeTechnique(io.qt.qt3d.render.@Nullable QTechnique t){
        removeTechnique_native_Qt3DRender_QTechnique_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(t));
    }
    
    @QtUninvokable
    private native void removeTechnique_native_Qt3DRender_QTechnique_ptr(long __this__nativeId, long t);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qeffect.html#techniques">Qt3DRender::QEffect::<wbr>techniques()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.qt3d.render.@Nullable QTechnique> techniques(){
        return techniques_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.qt3d.render.QTechnique> techniques_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QEffect(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QEffect(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QEffect instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QEffect(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QEffect() {
        this((io.qt.qt3d.core.QNode)null);
    }
}

==> qtjambi-qt3drender-6.7.0-sources.jar: io/qt/qt3d/render/QEffect.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Base class for effects in a Qt 3D scene</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qeffect.html">Qt3DRender::QEffect</a></code></p>
 */
public class QEffect extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QEffect.class);
    
    
    /**
     * <p>See <code>Qt3DRender::QEffect::<wbr/>QEffect(Qt3DCore::QNode*)</code></p>
     */
    @SuppressWarnings({"exports"})
    public QEffect(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QEffect instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qeffect.html#addParameter">Qt3DRender::QEffect::<wbr/>addParameter(Qt3DRender::QParameter*)</a></code></p>
     */
    @QtUninvokable
    public final void addParameter(io.qt.qt3d.render.@Nullable QParameter parameter){
        addParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parameter));
    }
    
    @QtUninvokable
    private native void addParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long parameter);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qeffect.html#addTechnique">Qt3DRender::QEffect::<wbr/>addTechnique(Qt3DRender::QTechnique*)</a></code></p>
     */
    @QtUninvokable
    public final void addTechnique(io.qt.qt3d.render.@Nullable QTechnique t){
        addTechnique_native_Qt3DRender_QTechnique_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(t));
    }
    
    @QtUninvokable
    private native void addTechnique_native_Qt3DRender_QTechnique_ptr(long __this__nativeId, long t);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qeffect.html#parameters">Qt3DRender::QEffect::<wbr/>parameters()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.qt3d.render.@Nullable QParameter> parameters(){
        return parameters_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.qt3d.render.QParameter> parameters_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qeffect.html#removeParameter">Qt3DRender::QEffect::<wbr/>removeParameter(Qt3DRender::QParameter*)</a></code></p>
     */
    @QtUninvokable
    public final void removeParameter(io.qt.qt3d.render.@Nullable QParameter parameter){
        removeParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parameter));
    }
    
    @QtUninvokable
    private native void removeParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long parameter);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qeffect.html#removeTechnique">Qt3DRender::QEffect::<wbr/>removeTechnique(Qt3DRender::QTechnique*)</a></code></p>
     */
    @QtUninvokable
    public final void removeTechnique(io.qt.qt3d.render.@Nullable QTechnique t){
        removeTechnique_native_Qt3DRender_QTechnique_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(t));
    }
    
    @QtUninvokable
    private native void removeTechnique_native_Qt3DRender_QTechnique_ptr(long __this__nativeId, long t);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qeffect.html#techniques">Qt3DRender::QEffect::<wbr/>techniques()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.qt3d.render.@Nullable QTechnique> techniques(){
        return techniques_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.qt3d.render.QTechnique> techniques_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QEffect(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QEffect(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QEffect instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QEffect(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QEffect() {
        this((io.qt.qt3d.core.QNode)null);
    }
}
